@@ -2,7 +2,7 @@
                     ansigenerator.cpp  -  description
                              -------------------
     begin                : Jul 5 2004
-    copyright            : (C) 2004-2007 by Andre Simon
+    copyright            : (C) 2004-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -48,7 +48,6 @@ string  AnsiGenerator::getOpenTag ( const string&font,
 
 AnsiGenerator::AnsiGenerator() : CodeGenerator ( ESC_ANSI )
 {
-
     newLineTag = "\n";
     spacer = initialSpacer = " ";
 }
@@ -57,8 +56,7 @@ AnsiGenerator::~AnsiGenerator() {}
 
 void AnsiGenerator::initOutputTags()
 {
-    string defaultColor = Platform::isDarkTerminal() ? "00": "30";
-    openTags.push_back ( getOpenTag ( "00", defaultColor) );
+    openTags.push_back ( getOpenTag ( "00", "39" ) );
     openTags.push_back ( getOpenTag ( "00", "31" ) ); //str
     openTags.push_back ( getOpenTag ( "00", "34" ) );//number
     openTags.push_back ( getOpenTag ( "00", "34" ) );//sl comment
@@ -66,10 +64,13 @@ void AnsiGenerator::initOutputTags()
     openTags.push_back ( getOpenTag ( "00", "35" ) );//escapeChar
     openTags.push_back ( getOpenTag ( "00", "35" ) );//directive
     openTags.push_back ( getOpenTag ( "00", "31" ) );//directive string
-    openTags.push_back ( getOpenTag ( "00", defaultColor ) );//linenum
-    openTags.push_back ( getOpenTag ( "00", "00" ) );//symbol
+    openTags.push_back ( getOpenTag ( "00", "39" ) );//linenum
+    openTags.push_back ( getOpenTag ( "00", "39" ) );//symbol
     openTags.push_back ( getOpenTag ( "00", "35" ) );//interpolation
 
+    openTags.push_back ( getOpenTag ( "01", "31" ) );//error
+    openTags.push_back ( getOpenTag ( "01", "31" ) );//warning
+
     closeTags.push_back ( "" );
     for (unsigned int i=1; i<NUMBER_BUILTIN_STATES; i++ ) {
         closeTags.push_back ( "\033[m" );
