@@ -2,7 +2,7 @@
                     bbcodegenerator.cpp  -  description
                              -------------------
     begin                : Jul 21 2009
-    copyright            : (C) 2004-2016 by Andre Simon
+    copyright            : (C) 2004-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -96,6 +96,8 @@ void BBCodeGenerator::initOutputTags ()
     openTags.push_back ( getOpenTag ( docStyle.getLineStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getOperatorStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getInterpolationStyle() ) );
+    openTags.push_back ( getOpenTag ( docStyle.getErrorStyle() ) );
+    openTags.push_back ( getOpenTag ( docStyle.getErrorMessageStyle() ) );
 
     closeTags.push_back ( getCloseTag ( docStyle.getDefaultStyle() ) );
     closeTags.push_back ( getCloseTag ( docStyle.getStringStyle() ) );
@@ -108,6 +110,8 @@ void BBCodeGenerator::initOutputTags ()
     closeTags.push_back ( getCloseTag ( docStyle.getLineStyle() ) );
     closeTags.push_back ( getCloseTag ( docStyle.getOperatorStyle() ) );
     closeTags.push_back ( getCloseTag ( docStyle.getInterpolationStyle() ) );
+    closeTags.push_back ( getCloseTag ( docStyle.getErrorStyle() ) );
+    closeTags.push_back ( getCloseTag ( docStyle.getErrorMessageStyle() ) );
 }
 
 string BBCodeGenerator::maskCharacter ( unsigned char c )
