@@ -2,7 +2,7 @@
                    xterm256generator.cpp  -  description
                              -------------------
     begin                : Oct 13 2006
-    copyright            : (C) 2006-2018 by Andre Simon
+    copyright            : (C) 2006-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -43,7 +43,7 @@ Xterm256Generator::Xterm256Generator() :
     canvasPadding(0)
 {
     newLineTag = "\n";
-    spacer = " ";
+    spacer = initialSpacer = " ";
 }
 
 Xterm256Generator::~Xterm256Generator() {}
@@ -60,7 +60,6 @@ void Xterm256Generator::printBody()
 
 string Xterm256Generator::getFooter()
 {
-    //return noTrailingNewLine ? "" : "\033[m";
     return string();
 }
 
@@ -79,7 +78,7 @@ void Xterm256Generator::initOutputTags ( )
         bg_rgb[0] = ( unsigned char ) strtoll ( bg.getRed ( HTML ).c_str(), NULL, 16 );
         bg_rgb[1] = ( unsigned char ) strtoll ( bg.getGreen ( HTML ).c_str(), NULL, 16 );
         bg_rgb[2] = ( unsigned char ) strtoll ( bg.getBlue ( HTML ).c_str(), NULL, 16 );
-        
+
         if (use16mColours) {
             //use 24bit true colour ("888" colours (aka 16 million))
             bgs << "\033[48;2;"<< ( int ) bg_rgb[0] << ";" << ( int ) bg_rgb[1] << ";" << ( int ) bg_rgb[2] << "m";
@@ -90,8 +89,8 @@ void Xterm256Generator::initOutputTags ( )
         }
         canvasColSeq = bgs.str();
         maskWsBegin = canvasColSeq;
-    }    
-    
+    }
+
     openTags.push_back ( getOpenTag ( docStyle.getDefaultStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getStringStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getNumberStyle() ) );
@@ -104,9 +103,12 @@ void Xterm256Generator::initOutputTags ( )
     openTags.push_back ( getOpenTag ( docStyle.getOperatorStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getInterpolationStyle()) );
 
+    openTags.push_back ( getOpenTag ( docStyle.getErrorStyle() ) );
+    openTags.push_back ( getOpenTag ( docStyle.getErrorMessageStyle()) );
+
     for (unsigned int i=0; i<NUMBER_BUILTIN_STATES; i++ ) {
         closeTags.push_back ( "\033[m" );
-    }    
+    }
 }
 
 string  Xterm256Generator::getOpenTag ( const ElementStyle &col )
@@ -118,9 +120,9 @@ string  Xterm256Generator::getOpenTag ( const ElementStyle &col )
     rgb[2] = ( unsigned char ) strtoll ( c.getBlue ( HTML ).c_str(), NULL, 16 );
 
     ostringstream s;
-    
+
     s << canvasColSeq;
-    
+
     s  << "\033[";
 
     if ( col.isBold() ) s << "1;";
@@ -134,7 +136,7 @@ string  Xterm256Generator::getOpenTag ( const ElementStyle &col )
         // apply color approximation, 256 colour palette (216 colours + 16 ansi + 24 gray) (colors are 24bit)
         s << "38;5;"<< ( int ) rgb2xterm ( rgb ) << "m";
     }
-    
+
     return  s.str();
 }
 
@@ -150,35 +152,41 @@ string Xterm256Generator::getKeywordCloseTag ( unsigned int styleID )
 
 string Xterm256Generator::getNewLine()
 {
-    string nlStr;
-    
+
+    ostringstream ss;
+
+    printSyntaxError(ss);
+
     if (canvasPadding>0) {
         unsigned int lastLineLength=getLastLineLength();
-        
+
         //adapt to long lines; avoid lag with very long lines
         if (lastLineLength<512 && lastLineLength > canvasPadding && lastLineLength)
             canvasPadding = lastLineLength;
-        
-        nlStr += canvasColSeq;
+
+        ss << canvasColSeq;
         if (canvasPadding > lastLineLength)
-            nlStr += string(canvasPadding - lastLineLength, ' ');
-        nlStr += "\033[m";    
-    } 
-    nlStr += (printNewLines) ? newLineTag : "";
-    return nlStr;
+            ss << string(canvasPadding - lastLineLength, ' ');
+        ss << "\033[m";
+    }
+
+    if (printNewLines)
+        ss << newLineTag;
+
+    return ss.str();
 }
 
- void Xterm256Generator::setESCTrueColor(bool b) { 
-    use16mColours = b; 
-    if (b) setOutputType(ESC_TRUECOLOR); 
-} 
-    
-void Xterm256Generator::setESCCanvasPadding(unsigned int p) { 
-    if (p<512) canvasPadding = p; 
+ void Xterm256Generator::setESCTrueColor(bool b) {
+    use16mColours = b;
+    if (b) setOutputType(ESC_TRUECOLOR);
+}
+
+void Xterm256Generator::setESCCanvasPadding(unsigned int p) {
+    if (p<512) canvasPadding = p;
 }
 
 /* the following functions are based on Wolfgang Frischs xterm256 converter utility:
-   http://frexx.de/xterm-256-notes/
+   https://web.archive.org/web/20060815160015/http://www.frexx.de/xterm-256-notes/
 */
 
 void Xterm256Generator::xterm2rgb ( unsigned char color, unsigned char* rgb )
@@ -206,7 +214,7 @@ void Xterm256Generator::xterm2rgb ( unsigned char color, unsigned char* rgb )
 
 void Xterm256Generator::maketable()
 {
-    unsigned char c, rgb[3];
+    unsigned char c, rgb[3] = {0};
     for ( c=0; c<=253; c++ ) {
         xterm2rgb ( c,rgb );
         colortable[c][0] = rgb[0];
