@@ -63,6 +63,7 @@ private:
     bool hoverProvider;
     bool semanticTokensProvider;
     bool logRequests;
+    bool legacyProtocol;
 
     std::string executable, workspace;
     std::string serverName, serverVersion;
@@ -122,6 +123,8 @@ public:
 
     void setSyntax ( const std::string& syntax );
 
+    void setLegacyProtocol ( bool legacy );
+
     bool connect();
 
     bool runInitialize();
