@@ -2,8 +2,8 @@
                         PreFormatter.cpp  -  description
                              -------------------
     begin                : Mo Jan 03 2005
-    copyright            : (C) 2005-2008 by Andre Simon
-    email                : andre.simon1@gmx.de
+    copyright            : (C) 2005-2021 by Andre Simon
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
